﻿using AutoSearch.Models;
using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Web;

namespace AutoSearch.Classes
{
    public class DataLoader
    {
        public void LoadData(HttpPostedFileBase file)
        {
            var list = new List<CSVDataModel>();
            //чтение данных из файла
            using (var sr = new StreamReader(file.InputStream, System.Text.Encoding.Default, true))
            {
                var fileText = sr.ReadToEnd();
                var lines = fileText.Split(new string[] { "\r\n" }, StringSplitOptions.RemoveEmptyEntries);
                foreach (var ln in lines.Skip(1)){
                    var parts = ln.Split(';');
                    list.Add(new CSVDataModel(parts[1], parts[2], parts[3], parts[4].ParseToType<int?>(), 
                        parts[5], parts[6], parts[7], parts[8].ParseToType<decimal?>(), parts[9], parts[10], parts[11]));
                };
            }
            //TODO валидация, если успею

            //запись данных в БД
            using (var db = new AutoEntities())
            {
                foreach (var offer in list)
                {
                    var mark = db.Marks.SingleOrDefault(a => a.name == offer.mark);
                    if (mark == null)
                    {
                        mark = new Mark() { name = offer.mark };
                        db.Marks.Add(mark);
                        db.SaveChanges();
                    }

                    var model = db.Models.SingleOrDefault(a => a.name == offer.model && a.markId == mark.id);
                    if (model == null)
                    {
                        model = new Model() { name = offer.model, markId = mark.id };
                        db.Models.Add(model);
                        db.SaveChanges();
                    }

                    var carcass = db.Carcasses.SingleOrDefault(a => a.name == offer.carcass);
                    if (carcass == null)
                    {
                        carcass = new Carcass() { name = offer.carcass };
                        db.Carcasses.Add(carcass);
                        db.SaveChanges();
                    }

                    var transmissionType = db.TransmissionTypes.SingleOrDefault(a => a.name == offer.transmissionType);
                    if (transmissionType == null)
                    {
                        transmissionType = new TransmissionType() { name = offer.transmissionType };
                        db.TransmissionTypes.Add(transmissionType);
                        db.SaveChanges();
                    }

                    var offerDb = new Offer()
                    {
                        carcassId = carcass.id,
                        color = offer.color,
                        contacts = offer.contacts,
                        cost = offer.cost.Value,
                        mileage = offer.mileage.Value,
                        modelId = model.id,
                        markId = mark.id,
                        productionYear = offer.productionYear.Value,
                        text = offer.text,
                        transmissionTypeId = transmissionType.id
                    };
                    db.Offers.Add(offerDb);
                    if (offer.photos != null)
                    {
                        foreach(var offerPhoto in offer.photos){
                            offerDb.OfferPhotoes.Add(new OfferPhoto()
                            {
                                photo = offerPhoto
                            });
                        }
                    }

                    db.SaveChanges();
                }
            }
        }


    }
}