﻿using AutoSearch.Models;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;

namespace AutoSearch.Controllers
{
    public class OfferController : Controller
    {
        public ActionResult Details(int id)
        {
            using (var db = new AutoEntities())
            {
                var offer = db.Offers.SingleOrDefault(a => a.id == id);
                if (offer == null)
                {
                    return View("NotFound");
                }

                var offerModel = new OfferModel(offer.Model.Mark.name, offer.Model.name, offer.Carcass.name, offer.productionYear,
                    offer.color, offer.mileage, offer.TransmissionType.name, offer.cost,
                    offer.OfferPhotoes.Any() ? offer.OfferPhotoes.Select(a => a.photo).ToArray() : null,
                    offer.text, offer.contacts);
                return View(offerModel);
            }
        }

        [HttpGet]
        public ActionResult Add()
        {
            using (var db = new AutoEntities())
            {
                var marks = db.Marks.Select(a => new {a.id, a.name}).ToList().Select(a => new SelectListItem
                {
                    Value = a.id.ToString(),
                    Text = a.name
                }).ToList();
                var carcasses = db.Carcasses.Select(a => new { a.id, a.name }).ToList().Select(a => new SelectListItem
                {
                    Value = a.id.ToString(),
                    Text = a.name
                }).ToList();
                var transmissionTypes = db.TransmissionTypes.Select(a => new { a.id, a.name }).ToList().Select(a => new SelectListItem
                {
                    Value = a.id.ToString(),
                    Text = a.name
                }).ToList();
                ViewData["marks"] = marks;
                ViewData["carcasses"] = carcasses;
                ViewData["transmissionTypes"] = transmissionTypes;
            }
            return View();
        }

        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult Add(AddOfferModel model)
        {
            //TODO проверка на XSS, если успею
            if (ModelState.IsValid == false)
            {
                using (var db = new AutoEntities())
                {
                    //TODO вынести получения ViewData в один метод, если успею
                    var marks = db.Marks.Select(a => new { a.id, a.name }).ToList().Select(a => new SelectListItem
                    {
                        Value = a.id.ToString(),
                        Text = a.name,
                        Selected = a.id == model.markId
                    }).ToList();
                    var models = db.Models.Where(a => a.markId == model.markId).Select(a => new { a.id, a.name }).ToList()
                    .Select(a => new SelectListItem
                    {
                        Value = a.id.ToString(),
                        Text = a.name,
                        Selected = a.id == model.modelId
                    }).ToList();
                    var carcasses = db.Carcasses.Select(a => new { a.id, a.name }).ToList().Select(a => new SelectListItem
                    {
                        Value = a.id.ToString(),
                        Text = a.name
                    }).ToList();
                    var transmissionTypes = db.TransmissionTypes.Select(a => new { a.id, a.name }).ToList().Select(a => new SelectListItem
                    {
                        Value = a.id.ToString(),
                        Text = a.name
                    }).ToList();
                    ViewData["carcasses"] = carcasses;
                    ViewData["transmissionTypes"] = transmissionTypes;
                    ViewData["marks"] = marks;
                    ViewData["models"] = models;
                }
                return View(model);
            }
            using (var db = new AutoEntities())
            {
                var offer = new Offer{
                    markId = model.markId, 
                    modelId = model.modelId,
                    cost = model.cost,
                    productionYear = model.productionYear,
                    mileage = model.mileage, 
                    color = model.color, 
                    carcassId = model.carcassId,
                    transmissionTypeId = model.transmissionTypeId,
                    text = model.text,
                    contacts = model.contacts
                };
                var photoes = model.photoes.Where(a => string.IsNullOrEmpty(a) == false).Distinct();
                db.Offers.Add(offer);
                foreach (var offerPhoto in photoes)
                {
                    offer.OfferPhotoes.Add(new OfferPhoto
                    {
                        photo = offerPhoto
                    });
                }
                db.SaveChanges();
            }
            return RedirectToAction("Success");
        }

        [HttpPost]
        public ActionResult GetModels(int markId)
        {
            using (var db = new AutoEntities())
            {
                var models = db.Models.Where(a => a.markId == markId).Select(a => new { a.id, a.name }).ToList()
                    .Select(a => new SelectListItem
                    {
                        Value = a.id.ToString(),
                        Text = a.name
                    }).ToList();
                return View(models);
            }
        }

        [HttpGet]
        public ActionResult Success()
        {
            return View();
        }
    }
}