﻿using AutoSearch.Models;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using AutoSearch.Classes;

namespace AutoSearch.Controllers
{
    public class SearchController : Controller
    {
        //
        // GET: /Search/
        public ActionResult Index()
        {
            using (var db = new AutoEntities())
            {
                var marks = db.Marks.Where(a => a.Models.Any(b => b.Offers.Any()))
                    .Select(a => new MarkAndModelWithCount 
                    {
                        id = a.id, 
                        name = a.name, 
                        count = db.Offers.Count(c => c.markId == a.id)
                    }).ToList();
                var marksCount = marks.Count;
                if (marksCount == 0)
                {
                    return View();
                }
                var columnCount = marksCount <= 5 ? 1 : marksCount <= 10 ? 2 : marksCount <= 15 ? 3 : 4;
                var splittedList = marks.Split(columnCount);
                var model = new SearchModel()
                {
                    marks = splittedList
                };
                return View(model);
            }
        }

        [HttpPost]
        public ActionResult LoadModels(int markId)
        {
            using (var db = new AutoEntities())
            {
                var models = db.Models.Where(a => a.markId == markId && a.Offers.Any())
                    .Select(a => new MarkAndModelWithCount 
                    { 
                        id = a.id, 
                        name = a.name, 
                        count = a.Offers.Count() 
                    }).ToList();
                var modelsCount = models.Count;
                if (modelsCount == 0)
                {
                    return View();
                }
                var columnCount = modelsCount <= 5 ? 1 : modelsCount <= 10 ? 2 : modelsCount <= 15 ? 3 : 4;
                var splittedList = models.Split(columnCount);
                var model = new SearchModel()
                {
                    models = splittedList
                };
                return View(model);
            }
        }

        [HttpPost]
        public ActionResult LoadOffers(int modelId)
        {
            using (var db = new AutoEntities())
            {
                var offers = db.Offers.Where(a => a.modelId == modelId)
                    .Select(a => new OfferInListModel
                    {
                        id = a.id,
                        cost = a.cost,
                        mileage = a.mileage,
                        name = a.Model.Mark.name + " " + a.Model.name,
                        productionYear = a.productionYear,
                        photo = a.OfferPhotoes.Any() ? a.OfferPhotoes.FirstOrDefault().photo : null
                    }).ToList();
                return View(offers);
            }
        }

        [HttpPost]
        public ActionResult MainSearch(MainSearchModel model)
        {
            using (var db = new AutoEntities())
            {
                var offers = (from a in db.Offers 
                             where (model.markId == null || a.markId == model.markId)
                             && (model.modelId == null || a.modelId == model.modelId)
                             && (model.yearFrom == null || a.productionYear >= model.yearFrom)
                             && (model.yearTo == null || a.productionYear <= model.yearTo)
                             && (model.costFrom == null || a.cost >= model.costFrom)
                             && (model.costTo == null || a.cost >= model.costTo)
                             && (model.mileageFrom == null || a.mileage >= model.mileageFrom)
                             && (model.mileageTo == null || a.mileage >= model.mileageTo)
                             select new OfferInListModel
                    {
                        id = a.id,
                        cost = a.cost,
                        mileage = a.mileage,
                        name = a.Model.Mark.name + " " + a.Model.name,
                        productionYear = a.productionYear,
                        photo = a.OfferPhotoes.Any() ? a.OfferPhotoes.FirstOrDefault().photo : null
                    }).ToList();
                return View("LoadOffers", offers);
            }
        }
	}
}