﻿using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Web;

namespace AutoSearch.Models
{
    public class OfferModel
    {
        /// <summary>
        /// ИД
        /// </summary>
        public int id { get; set; }

        [Display(Name="Название")]
        public string name { get; set; }

        [Display(Name="Цена")]
        public decimal cost { get; set; }

        [Display(Name="Год выпуска")]
        public int productionYear { get; set; }

        [Display(Name="Пробег")]
        public int mileage { get; set; }

        [Display(Name="Тип кузова")]
        public string carcass { get; set; }

        [Display(Name="Цвет")]
        public string color { get; set; }

        [Display(Name="КПП")]
        public string transmissionType { get; set; }

        [Display(Name="Текст объявления")]
        public string text { get; set; }

        [Display(Name="Контактная информация")]
        public string contacts { get; set; }

        /// <summary>
        /// Фотографии
        /// </summary>
        public string[] photos { get; set; }

        public OfferModel() { }

        public OfferModel(string mark, string model, string carcass, int productionYear, string color, int mileage, string transmissionType, decimal cost, string[] photos, string text, string contacts)
        {
            this.carcass = carcass;
            this.productionYear = productionYear;
            this.color = color;
            this.transmissionType = transmissionType;
            this.mileage = mileage;
            this.cost = cost;
            this.text = text;
            this.contacts = contacts;
            this.photos = photos;
            this.name = mark + " " + model;
        }
    }

    public class AddOfferModel
    {
        public int id { get; set; }

        [Required(ErrorMessage = "Не выбрана марка")]
        [Display(Name = "Марка")]
        public int markId { get; set; }

        [Required(ErrorMessage="Не выбрана модель")]
        [Display(Name="Модель")]
        public int modelId { get; set; }

        [Required(ErrorMessage = "Не указан год выпуска")]
        [Display(Name = "Год выпуска")]
        public int productionYear { get; set; }

        [Required(ErrorMessage = "Не указан пробег")]
        [Display(Name = "Пробег (км)")]
        public int mileage { get; set; }

        [Required(ErrorMessage = "Не указан цвет")]
        [Display(Name = "Цвет")]
        [StringLength(128, ErrorMessage="Длина поля не должна превышать 128 символов")]
        public string color { get; set; }

        [Required(ErrorMessage = "Не указан тип кузова")]
        [Display(Name = "Тип кузова")]
        public int carcassId { get; set; }

        [Required(ErrorMessage="Не укзаан тип КПП")]
        [Display(Name="Тип КПП")]
        public int transmissionTypeId { get; set; }

        [Required(ErrorMessage="Не указана цена")]
        [Display(Name="Цена (р.)")]
        public decimal cost { get; set; }

        [Required(ErrorMessage = "Не указаны контактные даные")]
        [Display(Name = "Контактные данные")]
        [StringLength(256, ErrorMessage = "Длина поля не должна превышать 256 символов")]
        public string contacts { get; set; }

        [Required(ErrorMessage = "Введите текст объявления")]
        [Display(Name = "Текст")]
        [StringLength(4000, ErrorMessage = "Длина поля не должна превышать 4000 символов")]
        public string text { get; set; }

        [Display(Name="Ссылки на фотографии")]
        public string[] photoes { get; set; }

        public AddOfferModel() { }
    }
}